# Create NONMEM data file from simulated data in PSM

rm(list=ls())

# Load the simulated data
load("NONMEM.RData")
names(SimDose.Data[[1]])
length(SimDose.Data)


# Round Observations and extract etas
etas <- c()
for( i in 1:length(SimDose.Data)) {
  SimDose.Data[[i]]$Y <- round(SimDose.Data[[i]]$Y , digits=3)
  etas[i]  <- SimDose.Data[[i]]$eta
  }

# Show the sampled etas
hist(etas,density=40)
qqnorm(etas)  ; abline(coef=c(0,1))


# Convert to NONMEM datafile
PKData <- as.data.frame( c() )
TL <- length(SimDose.Data[[1]]$Time)
PKData <- cbind(ID=rep(1,TL),TIME=SimDose.Data[[1]]$Time, DV=SimDose.Data[[1]]$Y[,])
for( i in 2:length(SimDose.Data)) {
  TL <- length(SimDose.Data[[i]]$Time)
  PKData <- rbind( PKData , cbind(ID=rep(i,TL),TIME=SimDose.Data[[i]]$Time, DV=SimDose.Data[[i]]$Y[,])  )
  }
PKData <- cbind( PKData , EVID=0)
PKData <- as.data.frame( PKData )

PKData$ID <- as.factor(PKData$ID)
xyplot(DV~TIME| ID , data=PKData, type="b")

# Check NoOfObservations pr. subject
tapply( PKData$DV , PKData$ID,function(x) length(x))

Dose <- merge( cbind(ID=1:10) , cbind(TIME=c(0,30.001,180.001),CMT=c(1,1,1),AMT=c(0.001,1500,1500),EVID=1))

PKData <- merge(PKData , Dose , all=TRUE)
PKData <- PKData[ order(PKData$ID , PKData$TIME, PKData$EVID) ,]

range(PKData$DV,na.rm=TRUE)
xyplot( DV~TIME|ID , PKData, type="l",lwd=2)

if(FALSE) {
  write.table(PKData, file = "NONMEMinputdata2.csv", append = FALSE, quote = FALSE, sep = "  ",
            eol = "\n", na = ".", dec = ".", row.names = FALSE,
            col.names = TRUE)
            }
